#ifndef NEON_H
#define NEON_H
#ifdef __cplusplus
extern "C" 
{
#endif

#ifdef _WIN32
#define DLLEXPORT __declspec(dllexport)
#elif __linux
#define DLLEXPORT
#endif
/*
This contaions the GIE Series Card SDK, Structure Class Function declarations & definitions.
*/

#ifndef NEONDIO_CONFIG_TYPE
#define NEONDIO_CONFIG_TYPE
enum DI_CONFIGTYPE
{
    DI_CONFIGTYPE_TRIGGER=0,
    DI_CONFIGTYPE_DIGITAL,
    DI_CONFIGTYPE_MAXIMUM
};

enum DO_CONFIGTYPE
{
    DO_CONFIGTYPE_STROBEOUT=0,
    DO_CONFIGTYPE_DIGITAL,
    DO_CONFIGTYPE_MAXIMUM
};

#endif

/*
@brief Return value definitions

Return values when a error occurs 
*/
#define FUN_UNSUPPORT -99
#define COMMON_ERROR -1
#define COMMON_BUSY -2

/* 
This function retrieve the device information.
@param sVersion - Output the device information
@param iSize - the size of sVersion
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetDeviceInfo(char* sVersion, int iSize);

//DIO
/* 
This function retrieve the numbers of DI.
@param iCounts - Output the numbers of DI
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetDINums(unsigned int* iCounts);

/* 
This function retrieve the numbers of DO.
@param iCounts - Output the numbers of DO
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetDONums(unsigned int* iCounts);

/* 
This function set the DO state.
@param iIndex - The index of DO (zero-based)
@param iState - The state for set
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_SetDOState(unsigned int iIndex,int iState);

/* 
This function retrieve the DO states list.
@param iIndex - The index of DO (zero-based)
@param iState - Output the DO state
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetDOState(unsigned int iIndex,int* iState);

/* 
This function retrieve the DI states list.
@param iIndex - The index of DI (zero-based)
@param iState - Output the DI state
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetDIState(unsigned int iIndex,int* iState);

/* 
This function set the DO0 config type.
@param iCfg_type - The config type for set
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_SetDO0Config(int iCfg_type);

/* 
This function get the DO0 config type.
@param iCfg_type - Output the config type
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetDO0Config(int* iCfg_type);

/* 
This function set the DI0 config type.
@param iCfg_type - The config type for set
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_SetDI0Config(int iCfg_type);

/* 
This function get the DI0 config type.
@param iCfg_type - Output the config type
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetDI0Config(int* iCfg_type);

//Camera Control
/*
This function is enable/disable Strobe out.
@param iEnable - 0 is disable or others enable
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_SetStrobeOutEnable(int iEnable);

/*
This function is get the enable state of the Strobe out.
@param iEnable - return the enable state
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetStrobeOutEnable(int* iEnable);

/* 
This function set Strobe Out delay.(microseconds)
@param iMicroSecond - Microseconds, set 0 is 1 microsecond
@return - Return true if success or COMMON_ERROR if failed.
*/              
DLLEXPORT int Neon_SetStrobeOutDelay(unsigned int iMicroSecond);

/*
This function get Strobe Out delay.(microseconds)
@param iMicroSecond - output Microseconds, set 0 is 1 microsecond
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetStrobeOutDelay(unsigned int* iMicroSecond);

/* 
This function set Strobe Out Pulse width.(microseconds)
@param iMicroSecond - Microseconds, set 0 is 1 microsecond
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_SetStrobeOutPulseWidth(unsigned int iMicroSecond);

/*
This function get Strobe Out Pulse width.(microseconds)
@param iMicroSecond - output Microseconds, set 0 is 1 microsecond
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetStrobeOutPulseWidth(unsigned int* iMicroSecond);


/* 
This function set Exposure out delay.(microseconds)
@param iMicroSecond - Microseconds, 0 is no delay
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_SetExposureDelay(unsigned int iMicroSecond);

/*
This function get Exposure out delay.(microseconds)
@param iMicroSecond - output Microseconds, 0 is no delay
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetExposureDelay(unsigned int* iMicroSecond);

/*
This function set Debounce filter time. (unit is clock cycle time: 40 ns)
@param iNtimes40ns - the nimbers of clock cycle
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_SetDebounceTime(unsigned int iNtimes40ns);

/*
This function get Debounce filter time. (unit is clock cycle time: 40 ns)
@param iNtimes40ns - output the nimbers of clock cycle
@return - Return true if success or COMMON_ERROR if failed.
*/
DLLEXPORT int Neon_GetDebounceTime(unsigned int* iNtimes40ns);

#ifdef __cplusplus
}
#endif
#endif // NEON_H
